from setuptools import setup

setup(name='asol_probability_dist',
      version='0.1',
      author="Andrew Leung",
      author_email="Andrew.sLeung@gmail.com",
      description='A package to visualize Gaussian and Binomial probability distributions',
      packages=['asol_probability_dist'],
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
      ],
      zip_safe=False)


